@@ -1,2 +1,2 @@
+from . import file_packager  # noqa: F401
 from .version import __version__  # noqa: F401
-from . import file_packager
